@@ -94,9 +94,14 @@ from .usecases.child_monitoring import ChildMonitoringConfig
 from .usecases.gender_detection import GenderDetectionConfig
 from .usecases.concrete_crack_detection import ConcreteCrackConfig
 from .usecases.fashion_detection import FashionDetectionConfig, FashionDetectionUseCase
+
 from .usecases.warehouse_object_segmentation import WarehouseObjectConfig
 from .usecases.shopping_cart_analysis import ShoppingCartConfig
 
+from .usecases.shoplifting_detection import ShopliftingDetectionConfig, ShopliftingDetectionUseCase
+from .usecases.defect_detection_products import BottleDefectUseCase, BottleDefectConfig
+from .usecases.assembly_line_detection import AssemblyLineUseCase, AssemblyLineConfig
+
 # Use case implementations
 from .usecases import (
     PeopleCountingUseCase,
@@ -133,7 +138,9 @@ from .usecases import (
     FashionDetectionUseCase,
     ConcreteCrackUseCase,
     WarehouseObjectUseCase,
-    ShoppingCartUseCase
+    ShoppingCartUseCase,
+    BottleDefectUseCase,
+    AssemblyLineUseCase
 )
 
 # Register use cases automatically
@@ -171,9 +178,15 @@ _gender_detection = GenderDetectionUseCase()
 _weapon_tracking = WeaponDetectionUseCase()
 _concrete_crack_detection = ConcreteCrackUseCase()
 _fashion_detection = FashionDetectionUseCase()
+
 _warehouse_object_segmentation = WarehouseObjectUseCase()
 _shopping_cart_analysis = ShoppingCartUseCase()
 
+
+_shoplifting_detection = ShopliftingDetectionUseCase()
+_defect_detection_products = BottleDefectUseCase()
+_assembly_line_detection = AssemblyLineUseCase()
+
 registry.register_use_case(_people_counting.category, _people_counting.name, PeopleCountingUseCase)
 registry.register_use_case(_customer_service.category, _customer_service.name, CustomerServiceUseCase)
 registry.register_use_case(_advanced_customer_service.category, _advanced_customer_service.name, AdvancedCustomerServiceUseCase)
@@ -209,9 +222,15 @@ registry.register_use_case(_child_monitoring.category, _child_monitoring.name, C
 registry.register_use_case(_weapon_tracking.category, _weapon_tracking.name, WeaponDetectionUseCase)
 registry.register_use_case(_concrete_crack_detection.category, _concrete_crack_detection.name, ConcreteCrackUseCase)
 registry.register_use_case(_fashion_detection.category, _fashion_detection.name, FashionDetectionUseCase)
+
 registry.register_use_case(_warehouse_object_segmentation.category, _warehouse_object_segmentation.name, WarehouseObjectUseCase)
 registry.register_use_case(_shopping_cart_analysis.category, _shopping_cart_analysis.name, ShoppingCartUseCase)
 
+
+registry.register_use_case(_shoplifting_detection.category, _shoplifting_detection.name, ShopliftingDetectionUseCase)
+registry.register_use_case(_defect_detection_products.category, _defect_detection_products.name, BottleDefectUseCase)
+registry.register_use_case(_assembly_line_detection.category, _assembly_line_detection.name, AssemblyLineUseCase)
+
 # Utility functions - organized by category
 from .utils import (  # noqa: E402
     # Geometry utilities
@@ -345,6 +364,7 @@ __all__ = [
     'ColorDetectionConfig',
     'LicensePlateConfig',
     'MaskDetectionConfig',
+    'ShopliftingDetectionConfig',
     'CarDamageConfig',
     'ParkingSpaceConfig',
     'PotholeConfig',
@@ -376,6 +396,10 @@ __all__ = [
     'WeaponDetectionConfig',
     'ConcreteCrackConfig',
     'FashionDetectionConfig',
+    'WarehouseObjectConfig',
+    'ShoppingCartConfig',
+    'BottleDefectConfig',
+    'AssemblyLineConfig',
 
     # Use case classes
     'PeopleCountingUseCase',
@@ -396,6 +420,7 @@ __all__ = [
     'UnderwaterPlasticUseCase',
     'PedestrianDetectionUseCase',
     'AgeDetectionUseCase',
+    'ShopliftingDetectionUseCase',
     'WeldDefectUseCase',
     'BananaMonitoringUseCase',
     'PriceTagUseCase',
@@ -412,6 +437,10 @@ __all__ = [
     'GenderDetectionUseCase',
     'ConcreteCrackUseCase',
     'FashionDetectionUseCase',
+    'WarehouseObjectUseCase',
+    'ShoppingCartUseCase',
+    'BottleDefectUseCase',
+    'AssemblyLineUseCase',
     
     # Base classes for extension
     'BaseProcessor',
