@@ -38,8 +38,13 @@ from ..usecases.gender_detection import GenderDetectionConfig, GenderDetectionUs
 from ..usecases.weapon_detection import WeaponDetectionUseCase,WeaponDetectionConfig
 from ..usecases.concrete_crack_detection import ConcreteCrackUseCase, ConcreteCrackConfig
 from ..usecases.fashion_detection import FashionDetectionUseCase, FashionDetectionConfig
+
 from ..usecases.warehouse_object_segmentation import WarehouseObjectUseCase, WarehouseObjectConfig
 from ..usecases.shopping_cart_analysis import ShoppingCartUseCase, ShoppingCartConfig
+from ..usecases.assembly_line_detection import AssemblyLineUseCase, AssemblyLineConfig
+
+from ..usecases.shoplifting_detection import ShopliftingDetectionConfig, ShopliftingDetectionUseCase
+from ..usecases.defect_detection_products import BottleDefectUseCase, BottleDefectConfig
 
 __all__ = [
     'PeopleCountingUseCase',
@@ -53,6 +58,8 @@ __all__ = [
     'VehicleMonitoringUseCase',
     'FireSmokeUseCase',
     'PotholeSegmentationUseCase',
+
+    'ShopliftingDetectionUseCase',
     'ParkingSpaceUseCase',
     'FlareAnalysisUseCase',
     'MaskDetectionUseCase',
@@ -77,6 +84,8 @@ __all__ = [
     'FashionDetectionUseCase',
     'WarehouseObjectUseCase',
     'ShoppingCartUseCase',
+    'BottleDefectUseCase',
+    'AssemblyLineUseCase',
 
 
 
@@ -93,6 +102,7 @@ __all__ = [
     'ParkingSpaceConfig',
     'MaskDetectionConfig',
     'FireSmokeConfig',
+    'ShopliftingDetectionConfig',
     'CarDamageConfig',
     'FlareAnalysisConfig',
     'FaceEmotionConfig',
@@ -114,5 +124,7 @@ __all__ = [
     'ConcreteCrackConfig',
     'FashionDetectionConfig',
     'WarehouseObjectConfig',
-    'ShoppingCartConfig'
+    'ShoppingCartConfig',
+    'BottleDefectConfig',
+    'AssemblyLineConfig'
 ]
