@@ -411,13 +411,18 @@ class ConfigManager:
             "solar_panel": None,
             "crop_weed_detection": None,
             "emergency_vehicle_detection": None,
+            "shoplifting_detection":None,
             "price_tag_detection": None,
             "child_monitoring": None,
             "weapon_detection" : None,
             "concrete_crack_detection": None,
             "fashion_detection": None,
+            "pothole_segmentation": None,
             "warehouse_object_segmentation": None,
             "shopping_cart_analysis": None,
+            "defect_detection_products": None,
+            'assembly_line_detection': None,
+
         }
 
     def register_config_class(self, usecase: str, config_class: type) -> None:
@@ -487,6 +492,14 @@ class ConfigManager:
             return FireSmokeConfig
         except ImportError:
             return None
+
+    def _get_shoplifting_detection_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.shoplifting_detection import ShopliftingDetectionConfig
+            return ShopliftingDetectionConfig
+        except ImportError:
+            return None
     
 
     def _get_car_damage_config_class(self):
@@ -656,6 +669,22 @@ class ConfigManager:
             return ShoppingCartAnalysisConfig
         except ImportError:
             return None
+    
+    def bottle_defect_detection_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.defect_detection_products import BottleDefectConfig
+            return BottleDefectConfig
+        except ImportError:
+            return None
+        
+    def assembly_line_detection_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.assembly_line_detection import AssemblyLineConfig
+            return AssemblyLineConfig
+        except ImportError:
+            return None
 
     def create_config(self, usecase: str, category: Optional[str] = None, **kwargs) -> BaseConfig:
         """
@@ -790,6 +819,21 @@ class ConfigManager:
                 alert_config=alert_config,
                 **kwargs
             )
+        elif usecase == "shoplifting_detection":
+            # Import here to avoid circular import
+            from ..usecases.shoplifting_detection import ShopliftingDetectionConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = ShopliftingDetectionConfig(
+                category=category or "mask_detection",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
 
         elif usecase == "fire_smoke_detection":
             # Import here to avoid circular import
@@ -1255,6 +1299,38 @@ class ConfigManager:
                 alert_config=alert_config,
                 **kwargs
             )
+        
+        elif usecase == "defect_detection_products":
+            # Import here to avoid circular import
+            from ..usecases.defect_detection_products import BottleDefectConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = BottleDefectConfig(
+                category=category or "retail",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
+        
+        elif usecase == "assembly_line_detection":
+            # Import here to avoid circular import
+            from ..usecases.assembly_line_detection import AssemblyLineConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = AssemblyLineConfig(
+                category=category or "manufacturing",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
             
         else:
             raise ConfigValidationError(f"Unknown use case: {usecase}")
@@ -1373,6 +1449,12 @@ class ConfigManager:
             default_config = FireSmokeConfig()
             return default_config.to_dict()
 
+        elif usecase == "shoplifting_detection":
+            # Import here to avoid circular import
+            from ..usecases.shoplifting_detection import ShopliftingDetectionConfig
+            default_config = ShopliftingDetectionConfig()
+            return default_config.to_dict()
+
         elif usecase == "solar_panel":
             # Import here to avoid circular import
             from ..usecases.solar_panel import SolarPanelConfig
@@ -1520,6 +1602,16 @@ class ConfigManager:
             from ..usecases.shopping_cart_analysis import ShoppingCartConfig
             default_config = ShoppingCartConfig()
             return default_config.to_dict()
+        elif usecase == "defect_detection_products":
+            # Import here to avoid circular import
+            from ..usecases.defect_detection_products import BottleDefectConfig
+            default_config = BottleDefectConfig()
+            return default_config.to_dict()
+        elif usecase == "assembly_line_detection":
+            # Import here to avoid circular import
+            from ..usecases.assembly_line_detection import AssemblyLineConfig
+            default_config = AssemblyLineConfig()
+            return default_config.to_dict()
 
         elif usecase not in self._config_classes:
             raise ConfigValidationError(f"Unsupported use case: {usecase}")
