@@ -36,10 +36,12 @@ from .usecases import (
     PotholeSegmentationUseCase,
     PPEComplianceUseCase,
     VehicleMonitoringUseCase,
+    ShopliftingDetectionUseCase,
     BananaMonitoringUseCase,
     MaskDetectionUseCase,
     CarDamageDetectionUseCase,
     FireSmokeUseCase,
+    ShopliftingDetectionConfig,
     FlareAnalysisUseCase,
     ParkingSpaceUseCase,
     FaceEmotionUseCase,
@@ -64,8 +66,9 @@ from .usecases import (
     ConcreteCrackUseCase,
     FashionDetectionUseCase,
     WarehouseObjectUseCase,
-    ShoppingCartUseCase
-
+    ShoppingCartUseCase,
+    BottleDefectUseCase,
+    AssemblyLineUseCase
 
 )
 
@@ -161,8 +164,13 @@ class PostProcessor:
         registry.register_use_case("security", "weapon_detection", WeaponDetectionUseCase)
         registry.register_use_case("general", "concrete_crack_detection", ConcreteCrackUseCase)
         registry.register_use_case("retail", "fashion_detection", FashionDetectionUseCase)
+
         registry.register_use_case("retail", "warehouse_object_segmentation", WarehouseObjectUseCase)
         registry.register_use_case("retail", "shopping_cart_analysis", ShoppingCartUseCase)
+
+        registry.register_use_case("security", "shoplifting_detection", ShopliftingDetectionUseCase)
+        registry.register_use_case("retail", "defect_detection_products", BottleDefectUseCase)
+        registry.register_use_case("manufacturing", "assembly_line_detection", AssemblyLineUseCase)
         
         logger.debug("Registered use cases with registry")
     
@@ -261,8 +269,6 @@ class PostProcessor:
                 result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, ChickenPoseDetectionUseCase):
                 result = use_case.process(data, parsed_config, context, stream_info)
-            elif isinstance(use_case, TheftDetectionUseCase):
-                result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, FlareAnalysisUseCase):
                 result = use_case.process(data, parsed_config,input_bytes, context, stream_info)
             elif isinstance(use_case,LicensePlateUseCase):
@@ -277,8 +283,16 @@ class PostProcessor:
                 result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, FashionDetectionUseCase):
                 result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, ShopliftingDetectionUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, PotholeSegmentationUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, AssemblyLineUseCase): 
+                result = use_case.process(data, parsed_config, context, stream_info)
+
             else:
                 result = use_case.process(data, parsed_config, context, stream_info)
+
             
             # Add processing time
             result.processing_time = time.time() - start_time
