@@ -40,9 +40,14 @@ from .gender_detection import GenderDetectionUseCase, GenderDetectionConfig
 from .weapon_detection import WeaponDetectionConfig,WeaponDetectionUseCase
 from .concrete_crack_detection import ConcreteCrackUseCase, ConcreteCrackConfig
 from .fashion_detection import FashionDetectionUseCase, FashionDetectionConfig
+
 from .warehouse_object_segmentation import WarehouseObjectUseCase, WarehouseObjectConfig
 from .shopping_cart_analysis import ShoppingCartUseCase, ShoppingCartConfig
 
+from .shoplifting_detection import ShopliftingDetectionConfig, ShopliftingDetectionUseCase
+from .defect_detection_products import BottleDefectUseCase, BottleDefectConfig
+from .assembly_line_detection import AssemblyLineUseCase, AssemblyLineConfig
+
 __all__ = [
     'PeopleCountingUseCase',
     'CustomerServiceUseCase',
@@ -53,6 +58,7 @@ __all__ = [
     'PPEComplianceUseCase',
     'BananaMonitoringUseCase',
     'VehicleMonitoringUseCase',
+    'ShopliftingDetectionUseCase',
     'ParkingSpaceUseCase',
     'FireSmokeUseCase',
     'MaskDetectionUseCase',
@@ -79,6 +85,8 @@ __all__ = [
     'FashionDetectionUseCase',
     'WarehouseObjectUseCase',
     'ShoppingCartUseCase',
+    'BottleDefectUseCase',
+    'AssemblyLineUseCase',
     'PeopleCountingConfig',
     'ParkingSpaceConfig',
     'CustomerServiceConfig',
@@ -90,6 +98,7 @@ __all__ = [
     'CarDamageConfig',
     'CarDamageConfig',
     'VehicleMonitoringConfig',
+    'ShopliftingDetectionConfig',
     'FireSmokeConfig',
     'FlareAnalysisConfig',
     'FaceEmotionConfig',
@@ -112,5 +121,7 @@ __all__ = [
     'ConcreteCrackConfig',
     'FashionDetectionConfig',
     'WarehouseObjectConfig',
-    'ShoppingCartConfig'
+    'ShoppingCartConfig',
+    'BottleDefectConfig',
+    'AssemblyLineConfig'
 ]
\ No newline at end of file
