@@ -117,6 +117,8 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
             human_text_lines.append(f"\t- Active Customers: {active_customers}")
             human_text_lines.append(f"\t\t- Queuing: {customers_queuing}")
             human_text_lines.append(f"\t\t- Being Served: {customers_being_served}")
+            human_text_lines.append(f"\t\t- Completed: {customers_completed}")
+            human_text_lines.append(f"\t\t- Left: {customers_left}")
             human_text_lines.append(f"\t- Active Staff: {active_staff}")
             human_text_lines.append(f"\t- Active Service Areas: {active_service_areas}")
             for area_name, area_info in service_areas_status.items():
@@ -126,10 +128,11 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
 
             human_text_lines.append("")
             human_text_lines.append(f"TOTAL SINCE @ {start_timestamp}:")
-            human_text_lines.append(f"\t- Total Unique Customers (Journeys): {total_journeys}")
+            human_text_lines.append(f"\t- Total Journeys: {total_journeys}")
+            for state in ["entering", "queuing", "being_served", "completed", "left"]:
+                count = journey_analytics.get("journey_states", {}).get(state, 0)
+                human_text_lines.append(f"\t\t- {state.replace('_', ' ').title()}: {count}")
             human_text_lines.append(f"\t- Total Unique Staff: {total_staff}")
-            human_text_lines.append(f"\t- Customers Completed: {customers_completed}")
-            human_text_lines.append(f"\t- Customers Left: {customers_left}")
             human_text_lines.append(f"\t- Average Wait Time: {avg_wait_time:.1f}s")
             human_text_lines.append(f"\t- Average Service Time: {avg_service_time:.1f}s")
             human_text_lines.append(f"\t- Average Journey Time: {avg_journey_time:.1f}s")
@@ -170,7 +173,7 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
                     "local_frame_id": str(frame_id)
                 },
                 "human_text": human_text,
-                "frame_id": str(frame_id),
+                "local_frame_id": str(frame_id),
                 "frames_in_this_call": 1,
                 "total_frames_processed": total_frames_processed + int(frame_id),
                 "current_frame_number": str(frame_id),
@@ -1088,11 +1091,14 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
                 customers_being_served += 1
 
         # Use global staff count (unique staff IDs)
-        total_staff = len(self.global_staff_ids)
+        # Use active_staff from staff_management_analytics for real-time ratio
+        staff_analytics = self._get_staff_management_results()
+        active_staff = staff_analytics.get("active_staff", 0)
+        total_staff = staff_analytics.get("total_staff", 0)
 
         metrics = {
             # Now using per-chunk customer count for ratio
-            "customer_to_staff_ratio": (customers_queuing + customers_being_served) / max(total_staff, 1),
+            "customer_to_staff_ratio": (customers_queuing + customers_being_served) / max(active_staff, 1),
             "service_efficiency": 0.0,
             "queue_performance": 0.0,
             "staff_productivity": 0.0,
@@ -1250,17 +1256,35 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
             return stream_time_str[:8] if stream_time_str else "00:00:00.00"
 
     def _get_start_timestamp_str(self, stream_info: Optional[dict]) -> str:
-        """Get formatted start timestamp for the stream (video or stream)."""
+        """Get formatted start timestamp for 'TOTAL SINCE' based on stream type."""
+        # For video, use start_video_timestamp if available, else 00:00:00
         if not stream_info:
             return "00:00:00.00"
         input_settings = stream_info.get("input_settings", {})
         stream_type = input_settings.get("stream_type", "video_file")
         if stream_type == "video_file":
-            start_video_timestamp = stream_info.get("start_video_timestamp", "")
-            return start_video_timestamp[:8] if start_video_timestamp else "00:00:00.00"
+            start_video_timestamp = stream_info.get("start_video_timestamp", None)
+            if start_video_timestamp:
+                return start_video_timestamp[:8]
+            else:
+                return "00:00:00.00"
         else:
-            start_stream_time = stream_info.get("start_stream_time", "")
-            return start_stream_time[:8] if start_stream_time else "00:00:00.00"
+            # For streams, persist the first stream_time as tracking start time
+            if not hasattr(self, "_tracking_start_time") or self._tracking_start_time is None:
+                stream_time_str = stream_info.get("stream_time", "")
+                if stream_time_str:
+                    try:
+                        from datetime import datetime, timezone
+                        timestamp_str = stream_time_str.replace(" UTC", "")
+                        dt = datetime.strptime(timestamp_str, "%Y-%m-%d-%H:%M:%S.%f")
+                        self._tracking_start_time = dt.replace(tzinfo=timezone.utc).timestamp()
+                    except Exception:
+                        self._tracking_start_time = time.time()
+                else:
+                    self._tracking_start_time = time.time()
+            from datetime import datetime, timezone
+            dt = datetime.fromtimestamp(self._tracking_start_time, tz=timezone.utc)
+            return dt.strftime('%Y:%m:%d %H:%M:%S')
     
     def _generate_summary(self, analytics_results: Dict, alerts: List) -> str:
         """Generate human-readable summary."""
