@@ -22,16 +22,16 @@ from ..core.config import BaseConfig, AlertConfig, ZoneConfig
 
 @dataclass
 class ConcreteCrackConfig(BaseConfig):
-    """Configuration for concrete crack detection use case in concrete crack monitoring."""
+    """Configuration for Concrete Crack detection use case in Concrete Crack monitoring."""
     # Smoothing configuration
     enable_smoothing: bool = True
     smoothing_algorithm: str = "observability"  # "window" or "observability"
-    smoothing_window_size: int = 10
+    smoothing_window_size: int = 20
     smoothing_cooldown_frames: int = 5
-    smoothing_confidence_range_factor: float = 0.2
+    smoothing_confidence_range_factor: float = 0.5
 
     #confidence thresholds
-    confidence_threshold: float = 0.3
+    confidence_threshold: float = 0.6
 
     usecase_categories: List[str] = field(
         default_factory=lambda: ['Cracks']
@@ -45,8 +45,7 @@ class ConcreteCrackConfig(BaseConfig):
 
     index_to_category: Optional[Dict[int, str]] = field(
         default_factory=lambda: {
-           0:"Cracks"
-
+            0: "Cracks",
         }
     )
 
@@ -268,7 +267,7 @@ class ConcreteCrackUseCase(BaseProcessor):
                     smoothing_algorithm=config.smoothing_algorithm,
                     window_size=config.smoothing_window_size,
                     cooldown_frames=config.smoothing_cooldown_frames,
-                    confidence_threshold=config.confidence_threshold,  # Use concrete_crack threshold as default
+                    confidence_threshold=config.confidence_threshold,  # Use Concrete Crack threshold as default
                     confidence_range_factor=config.smoothing_confidence_range_factor,
                     enable_smoothing=True
                 )
@@ -468,7 +467,6 @@ class ConcreteCrackUseCase(BaseProcessor):
             stream_info: Optional[Dict[str, Any]] = None
     ) -> List[Dict]:
         """Generate structured tracking stats for the output format with frame-based keys, including track_ids_info."""
-
         frame_key = str(frame_number) if frame_number is not None else "current_frame"
         tracking_stats = [{frame_key: []}]
         frame_tracking_stats = tracking_stats[0][frame_key]
@@ -513,8 +511,8 @@ class ConcreteCrackUseCase(BaseProcessor):
         human_text = "\n".join(human_text_lines)
 
         tracking_stat = {
-            "type": "concrete_crack_tracking",
-            "category": "concrete_crack",
+            "type": "concrete_crack_detection",
+            "category": "general",
             "count": total_detections,
             "insights": insights,
             "summary": summary,
@@ -522,7 +520,8 @@ class ConcreteCrackUseCase(BaseProcessor):
             "human_text": human_text,
             "track_ids_info": track_ids_info,
             "global_frame_offset": getattr(self, '_global_frame_offset', 0),
-            "local_frame_id": frame_key
+            "local_frame_id": frame_key,
+            "detections": counting_summary.get("detections", [])  # Added line to include detections
         }
 
         frame_tracking_stats.append(tracking_stat)
@@ -556,7 +555,7 @@ class ConcreteCrackUseCase(BaseProcessor):
 
     # Human-friendly display names for  categories
     CATEGORY_DISPLAY = {
-        "Cracks": "Cracks"
+        "Cracks": "Cracks",
     }
 
     def _generate_insights(self, summary: dict, config: ConcreteCrackConfig) -> List[str]:
