@@ -475,8 +475,7 @@ class PotholeSegmentationUseCase(BaseProcessor):
             frame_number: Optional[int] = None,
             stream_info: Optional[Dict[str, Any]] = None
     ) -> List[Dict]:
-        """Generate structured tracking stats for the output format with frame-based keys, including track_ids_info."""
-
+        """Generate structured tracking stats for the output format with frame-based keys, including track_ids_info and detections with masks."""
         frame_key = str(frame_number) if frame_number is not None else "current_frame"
         tracking_stats = [{frame_key: []}]
         frame_tracking_stats = tracking_stats[0][frame_key]
@@ -511,7 +510,7 @@ class PotholeSegmentationUseCase(BaseProcessor):
 
         # TOTAL SINCE section
         human_text_lines.append(f"TOTAL SINCE {start_timestamp}:")
-        human_text_lines.append(f"\t- Total  Detected: {cumulative_total}")
+        human_text_lines.append(f"\t- Total Detected: {cumulative_total}")
         # Add category-wise counts
         if total_counts:
             for cat, count in total_counts.items():
@@ -520,6 +519,19 @@ class PotholeSegmentationUseCase(BaseProcessor):
 
         human_text = "\n".join(human_text_lines)
 
+        # Include detections with masks from counting_summary
+        detections = [
+            {
+                "category": det.get("category"),
+                "confidence": det.get("confidence"),
+                "bounding_box": det.get("bounding_box"),
+                "track_id": det.get("track_id"),
+                "frame_id": det.get("frame_id"),
+                "masks": det.get("masks", det.get("mask", []))  # Include masks, fallback to empty list
+            }
+            for det in counting_summary.get("detections", [])
+        ]
+
         tracking_stat = {
             "type": "pothole_segmentation",
             "category": "infrastructure",
@@ -530,7 +542,8 @@ class PotholeSegmentationUseCase(BaseProcessor):
             "human_text": human_text,
             "track_ids_info": track_ids_info,
             "global_frame_offset": getattr(self, '_global_frame_offset', 0),
-            "local_frame_id": frame_key
+            "local_frame_id": frame_key,
+            "detections": detections  # Add detections with masks
         }
 
         frame_tracking_stats.append(tracking_stat)
@@ -539,27 +552,30 @@ class PotholeSegmentationUseCase(BaseProcessor):
     def _count_categories(self, detections: list, config: PotholeConfig) -> dict:
         """
         Count the number of detections per category and return a summary dict.
-        The detections list is expected to have 'track_id' (from tracker), 'category', 'bounding_box', etc.
-        Output structure will include 'track_id' for each detection as per AdvancedTracker output.
+        The detections list is expected to have 'track_id' (from tracker), 'category', 'bounding_box', 'masks', etc.
+        Output structure will include 'track_id' and 'masks' for each detection as per AdvancedTracker output.
         """
         counts = {}
+        valid_detections = []
         for det in detections:
             cat = det.get('category', 'unknown')
+            if not all(k in det for k in ['category', 'confidence', 'bounding_box']):  # Validate required fields
+                self.logger.warning(f"Skipping invalid detection: {det}")
+                continue
             counts[cat] = counts.get(cat, 0) + 1
-        # Each detection dict will now include 'track_id' (and possibly 'frame_id')
+            valid_detections.append({
+                "bounding_box": det.get("bounding_box"),
+                "category": det.get("category"),
+                "confidence": det.get("confidence"),
+                "track_id": det.get("track_id"),
+                "frame_id": det.get("frame_id"),
+                "masks": det.get("masks", det.get("mask", []))  # Include masks, fallback to empty list
+            })
+        self.logger.debug(f"Valid detections after filtering: {len(valid_detections)}")
         return {
             "total_count": sum(counts.values()),
             "per_category_count": counts,
-            "detections": [
-                {
-                    "bounding_box": det.get("bounding_box"),
-                    "category": det.get("category"),
-                    "confidence": det.get("confidence"),
-                    "track_id": det.get("track_id"),
-                    "frame_id": det.get("frame_id")
-                }
-                for det in detections
-            ]
+            "detections": valid_detections
         }
 
     # Human-friendly display names for  categories
