@@ -31,7 +31,7 @@ class ShoppingCartConfig(BaseConfig):
     smoothing_confidence_range_factor: float = 0.5
 
     #confidence thresholds
-    confidence_threshold: float = 0.6
+    confidence_threshold: float = 0.2
 
     usecase_categories: List[str] = field(
         default_factory=lambda: ['Shelf','Shopping-trolley']
@@ -522,7 +522,8 @@ class ShoppingCartUseCase(BaseProcessor):
             "human_text": human_text,
             "track_ids_info": track_ids_info,
             "global_frame_offset": getattr(self, '_global_frame_offset', 0),
-            "local_frame_id": frame_key
+            "local_frame_id": frame_key,
+            "detections": counting_summary.get("detections", []) 
         }
 
         frame_tracking_stats.append(tracking_stat)
